@@ -779,6 +779,8 @@ setGeneric("refID",function(object) standardGeneric("refID"))
 setMethod(f="refID",signature="bamAlign",definition=function(object) {return(.Call("bam_align_get_refid",object@align,PACKAGE="rbamtools"))})
 setGeneric("position",function(object) standardGeneric("position"))
 setMethod(f="position",signature="bamAlign",definition=function(object) {return(.Call("bam_align_get_position",object@align,PACKAGE="rbamtools"))})
+setGeneric("cigarSize",function(object) standardGeneric("cigarSize"))
+setMethod(f="cigarSize",signature="bamAlign",definition=function(object) {return(.Call("bam_align_get_cigar_size",object@align,PACKAGE="rbamtools"))})
 setGeneric("cigarData",function(object) standardGeneric("cigarData"))
 setMethod(f="cigarData",signature="bamAlign",definition=function(object) { .Call("bam_align_get_cigar_df",object@align,PACKAGE="rbamtools")})
 setGeneric("mateRefID",function(object) standardGeneric("mateRefID"))
